Installation — vedis-python 0.1.2 documentation

### Navigation

- index
- next |
- previous |
- vedis-python 0.1.2 documentation »

# Installation

You can use `pip` to install `vedis-python`:

    pip install vedis

The project is hosted at https://github.com/coleifer/vedis-python and can be installed from source:

    git clone https://github.com/coleifer/vedis-python
    cd vedis-python
    python setup.py build
    python setup.py install

After installing vedis-python, you can run the unit tests by executing the vedis.tests module:

    python vedis/tests.py

### Navigation

- index
- next |
- previous |
- vedis-python 0.1.2 documentation »